import paho.mqtt.client as mqtt
import logging

# 配置日志
logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(levelname)s - %(message)s')

# MQTT 客户端回调函数
def on_connect(client, userdata, flags, rc):
    logging.info("已连接到MQTT服务器")
    client.subscribe(topic)

def on_message(client, userdata, msg):
    logging.info(f"接收到消息: {msg.payload.decode()}")

if __name__ == "__main__":
    broker_address = "192.168.5.218"
    port = 1883
    topic = "/meeting/sign/result"  # 替换为你需要订阅的主题

    # 创建 MQTT 客户端实例
    mqtt_client = mqtt.Client()

    # 设置回调函数
    mqtt_client.on_connect = on_connect
    mqtt_client.on_message = on_message

    try:
        # 连接到 MQTT 服务器
        mqtt_client.connect(broker_address, port)

        # 启动网络循环
        mqtt_client.loop_forever()

    except Exception as e:
        logging.error(f"连接MQTT服务器时发生错误: {e}")

    finally:
        # 断开与 MQTT 服务器的连接
        mqtt_client.disconnect()